OSQAr Project (C)
=================

This is a minimal OSQAr documentation scaffold.

.. toctree::
   :maxdepth: 1

   01_requirements
   02_architecture
   03_verification
   04_implementation
   05_test_results
   06_lifecycle_management
